==> sblu-0.5.0-py3-none-any.whl: sblu/cli/cluspro/cmd_download.py <==
import click
import requests
import json
import sys

from sblu import CONFIG
from sblu.cli import pass_context
from sblu.cli.cluspro import make_sig

URL_SCHEME = "https"
API_ENDPOINT = "/api_download.php"
CP_CONFIG = CONFIG['cluspro']
FORM_KEYS = [
    'username', 'secret', 'jobid'
]


@click.command('download', short_help="Download jobs from ClusPro.")
@click.option("--username", default=CP_CONFIG['username'])
@click.option("--secret", default=CP_CONFIG['api_secret'])
@click.option("--server", default=CP_CONFIG['server'])
@click.argument("jobids", nargs=-1, required=True)
@pass_context
def cli(ctx,
        username, secret, server,
        jobids):
    if username is None or username == "None" or secret is None or secret == "None":
        if username is None or username == "None":
            username = click.prompt("Please enter your cluspro username")
            CP_CONFIG['username'] = username
        if secret is None or secret == "None":
            secret = click.prompt("Please enter your cluspro api secret")
            CP_CONFIG['api_secret'] = secret
        CONFIG.write()

    api_address = "{0}://{1}{2}".format(URL_SCHEME, server, API_ENDPOINT)
    for jobid in jobids:
        form = {
            k: v for k, v in locals().items() if k in FORM_KEYS and v is not None
        }

        form['sig'] = make_sig(form, secret)
        print(form)

        try:
            print("Downloading {}...".format(jobid), end="", file=sys.stderr)
            r = requests.post(api_address, data=form)

            if r.status_code != requests.codes.ok:
                print("ERROR", file=sys.stderr)
                for e in json.loads(r.text)['errors']:
                    print(e, file=sys.stderr)
                continue
            else:
                with open("cluspro.{}.tar.bz2".format(jobid), "wb") as out:
                    out.write(r.content)
            print("OK", file=sys.stderr)
        except:
            print("Error downloading job {}".format(jobid), file=sys.stderr)

==> sblu-0.5.1-py3-none-any.whl: sblu/cli/cluspro/cmd_download.py <==
import logging
import click
import requests
import json
import sys

from sblu import CONFIG
from sblu.cli.cluspro import make_sig

logger = logging.getLogger(__name__)

URL_SCHEME = "https"
API_ENDPOINT = "/api_download.php"
CP_CONFIG = CONFIG['cluspro']
FORM_KEYS = [
    'username', 'secret', 'jobid'
]


@click.command('download', short_help="Download jobs from ClusPro.")
@click.option("--username", default=CP_CONFIG['username'])
@click.option("--secret", default=CP_CONFIG['api_secret'])
@click.option("--server", default=CP_CONFIG['server'])
@click.argument("jobids", nargs=-1, required=True)
def cli(username, secret, server,
        jobids):
    if username is None or username == "None" or secret is None or secret == "None":
        if username is None or username == "None":
            username = click.prompt("Please enter your cluspro username")
            CP_CONFIG['username'] = username
        if secret is None or secret == "None":
            secret = click.prompt("Please enter your cluspro api secret")
            CP_CONFIG['api_secret'] = secret
        CONFIG.write()

    api_address = "{0}://{1}{2}".format(URL_SCHEME, server, API_ENDPOINT)
    for jobid in jobids:
        form = {
            k: v for k, v in locals().items() if k in FORM_KEYS and v is not None
        }

        form['sig'] = make_sig(form, secret)
        print(form)

        try:
            print("Downloading {}...".format(jobid), end="", file=sys.stderr)
            r = requests.post(api_address, data=form)

            if r.status_code != requests.codes.ok:
                print("ERROR", file=sys.stderr)
                for e in json.loads(r.text)['errors']:
                    print(e, file=sys.stderr)
                continue
            else:
                with open("cluspro.{}.tar.bz2".format(jobid), "wb") as out:
                    out.write(r.content)
            print("OK", file=sys.stderr)
        except:
            logger.error("Error downloading job {}".format(jobid))
